@@ -1,6 +1,6 @@
 __version_info__ = {
     'major': 1,
-    'minor': 2,
+    'minor': 4,
     'micro': 2,
     'releaselevel': 'final',
     'serial': 1
@@ -19,11 +19,15 @@ def get_version(short=False):
 __version__ = get_version()
 
 
-try:
+default_app_config = 'categories.apps.CategoriesConfig'
+
+
+def register():
     from categories import settings
-    from categories.registration import (_process_registry, register_fk,
-                                        register_m2m)
-    _process_registry(settings.FK_REGISTRY, register_fk)
-    _process_registry(settings.M2M_REGISTRY, register_m2m)
-except:
-    pass
+    from categories.registration import (_process_registry, registry)
+    _process_registry(settings.FK_REGISTRY, registry.register_fk)
+    _process_registry(settings.M2M_REGISTRY, registry.register_m2m)
+try:
+    register()
+except Exception as e:
+    print(e)
