@@ -9,7 +9,7 @@ from django.shortcuts import render_to_response
 
 import django
 
-import settings
+from . import settings
 
 
 class TreeEditorQuerySet(QuerySet):
@@ -38,8 +38,7 @@ class TreeEditorQuerySet(QuerySet):
             # will already be in include_pages when they are checked, thus not
             # trigger additional queries.
             for p in super(TreeEditorQuerySet, self.order_by('rght')).iterator():
-                if p.parent_id and p.parent_id not in include_pages and \
-                                   p.id not in include_pages:
+                if p.parent_id and p.parent_id not in include_pages and p.id not in include_pages:
                     ancestor_id_list = p.get_ancestors().values_list('id', flat=True)
                     include_pages.update(ancestor_id_list)
 
@@ -80,8 +79,8 @@ class TreeChangeList(ChangeList):
         else:
             return []
 
-    def get_query_set(self, *args, **kwargs):
-        qs = super(TreeChangeList, self).get_query_set(*args, **kwargs).order_by('tree_id', 'lft')
+    def get_queryset(self, *args, **kwargs):
+        qs = super(TreeChangeList, self).get_queryset(*args, **kwargs).order_by('tree_id', 'lft')
         return qs
 
 
@@ -125,7 +124,7 @@ class TreeEditor(admin.ModelAdmin):
         "The 'change list' admin view for this model."
         from django.contrib.admin.views.main import ERROR_FLAG
         from django.core.exceptions import PermissionDenied
-        from django.utils.encoding import force_unicode
+        from django.utils.encoding import force_text
         from django.utils.translation import ungettext
         opts = self.model._meta
         app_label = opts.app_label
@@ -145,12 +144,14 @@ class TreeEditor(admin.ModelAdmin):
 
         try:
             if django.VERSION[1] < 4:
-                params = (request, self.model, list_display,
+                params = (
+                    request, self.model, list_display,
                     self.list_display_links, self.list_filter, self.date_hierarchy,
                     self.search_fields, self.list_select_related,
                     self.list_per_page, self.list_editable, self)
             else:
-                params = (request, self.model, list_display,
+                params = (
+                    request, self.model, list_display,
                     self.list_display_links, self.list_filter, self.date_hierarchy,
                     self.search_fields, self.list_select_related,
                     self.list_per_page, self.list_max_show_all,
@@ -162,7 +163,7 @@ class TreeEditor(admin.ModelAdmin):
             # parameter via the query string. If wacky parameters were given and
             # the 'invalid=1' parameter was already in the query string, something
             # is screwed up with the database, so display an error page.
-            if ERROR_FLAG in request.GET.keys():
+            if ERROR_FLAG in list(request.GET.keys()):
                 return render_to_response(
                     'admin/invalid_setup.html', {'title': _('Database error')})
             return HttpResponseRedirect(request.path + '?' + ERROR_FLAG + '=1')
@@ -171,7 +172,7 @@ class TreeEditor(admin.ModelAdmin):
         # Try to look up an action first, but if this isn't an action the POST
         # will fall through to the bulk edit check, below.
         if actions and request.method == 'POST':
-            response = self.response_action(request, queryset=cl.get_query_set())
+            response = self.response_action(request, queryset=cl.get_queryset())
             if response:
                 return response
 
@@ -199,15 +200,15 @@ class TreeEditor(admin.ModelAdmin):
 
                 if changecount:
                     if changecount == 1:
-                        name = force_unicode(opts.verbose_name)
+                        name = force_text(opts.verbose_name)
                     else:
-                        name = force_unicode(opts.verbose_name_plural)
+                        name = force_text(opts.verbose_name_plural)
                     msg = ungettext(
                         "%(count)s %(name)s was changed successfully.",
                         "%(count)s %(name)s were changed successfully.",
                         changecount) % {'count': changecount,
                                         'name': name,
-                                        'obj': force_unicode(obj)}
+                                        'obj': force_text(obj)}
                     self.message_user(request, msg)
 
                 return HttpResponseRedirect(request.get_full_path())
@@ -244,23 +245,23 @@ class TreeEditor(admin.ModelAdmin):
         if django.VERSION[1] < 4:
             context['root_path'] = self.admin_site.root_path
         else:
-            selection_note_all = ungettext('%(total_count)s selected',
-                'All %(total_count)s selected', cl.result_count)
+            selection_note_all = ungettext('%(total_count)s selected', 'All %(total_count)s selected', cl.result_count)
 
             context.update({
-                'module_name': force_unicode(opts.verbose_name_plural),
+                'module_name': force_text(opts.verbose_name_plural),
                 'selection_note': _('0 of %(cnt)s selected') % {'cnt': len(cl.result_list)},
                 'selection_note_all': selection_note_all % {'total_count': cl.result_count},
             })
         context.update(extra_context or {})
         context_instance = template.RequestContext(
-            request, current_app=self.admin_site.name
+            request,
+            context
         )
         return render_to_response(self.change_list_template or [
             'admin/%s/%s/change_list.html' % (app_label, opts.object_name.lower()),
             'admin/%s/change_list.html' % app_label,
             'admin/change_list.html'
-        ], context, context_instance=context_instance)
+        ], context=context_instance)
 
     def changelist_view(self, request, extra_context=None, *args, **kwargs):
         """
@@ -270,17 +271,15 @@ class TreeEditor(admin.ModelAdmin):
         extra_context = extra_context or {}
         extra_context['EDITOR_MEDIA_PATH'] = settings.MEDIA_PATH
         extra_context['EDITOR_TREE_INITIAL_STATE'] = settings.TREE_INITIAL_STATE
-        if django.VERSION[1] >= 2:
-            return super(TreeEditor, self).changelist_view(
-                                    request, extra_context, *args, **kwargs)
-        else:
-            return self.old_changelist_view(request, extra_context)
 
-    def queryset(self, request):
+        # FIXME
+        return self.old_changelist_view(request, extra_context)
+
+    def get_queryset(self, request):
         """
         Returns a QuerySet of all model instances that can be edited by the
         admin site. This is used by changelist_view.
         """
-        qs = self.model._default_manager.get_query_set()
+        qs = self.model._default_manager.get_queryset()
         qs.__class__ = TreeEditorQuerySet
         return qs
