@@ -14,13 +14,9 @@ class Command(BaseCommand):
         """
         Alter the tables
         """
-        try:
-            from south.db import db
-        except ImportError:
-            raise ImproperlyConfigured("South must be installed for this command to work")
 
         from categories.migration import drop_field
         if len(args) != 3:
-            print "You must specify an Application name, a Model name and a Field name"
+            print("You must specify an Application name, a Model name and a Field name")
 
         drop_field(*args)
