@@ -1,14 +1,17 @@
 from django.core.urlresolvers import reverse
 from django.db import models
-from django.utils.encoding import force_unicode
+from django.utils.encoding import force_text
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.contenttypes import generic
+from functools import reduce
+try:
+    from django.contrib.contenttypes.fields import GenericForeignKey
+except ImportError:
+    from django.contrib.contenttypes.generic import GenericForeignKey
 from django.core.files.storage import get_storage_class
 
 from django.utils.translation import ugettext_lazy as _
 
-from .settings import (RELATION_MODELS, RELATIONS, THUMBNAIL_UPLOAD_PATH,
-                        THUMBNAIL_STORAGE)
+from .settings import (RELATION_MODELS, RELATIONS, THUMBNAIL_UPLOAD_PATH, THUMBNAIL_STORAGE)
 
 from .base import CategoryBase
 
@@ -51,11 +54,16 @@ class Category(CategoryBase):
 
     def get_absolute_url(self):
         """Return a path"""
+        from django.core.urlresolvers import NoReverseMatch
+
         if self.alternate_url:
             return self.alternate_url
-        prefix = reverse('categories_tree_list')
+        try:
+            prefix = reverse('categories_tree_list')
+        except NoReverseMatch:
+            prefix = '/'
         ancestors = list(self.get_ancestors()) + [self, ]
-        return prefix + '/'.join([force_unicode(i.slug) for i in ancestors]) + '/'
+        return prefix + '/'.join([force_text(i.slug) for i in ancestors]) + '/'
 
     if RELATION_MODELS:
         def get_related_content_type(self, content_type):
@@ -106,14 +114,14 @@ class CategoryRelationManager(models.Manager):
         """
         Get all the items of the given content type related to this item.
         """
-        qs = self.get_query_set()
+        qs = self.get_queryset()
         return qs.filter(content_type__name=content_type)
 
     def get_relation_type(self, relation_type):
         """
         Get all the items of the given relationship type related to this item.
         """
-        qs = self.get_query_set()
+        qs = self.get_queryset()
         return qs.filter(relation_type=relation_type)
 
 
@@ -123,9 +131,10 @@ class CategoryRelation(models.Model):
     content_type = models.ForeignKey(
         ContentType, limit_choices_to=CATEGORY_RELATION_LIMITS, verbose_name=_('content type'))
     object_id = models.PositiveIntegerField(verbose_name=_('object id'))
-    content_object = generic.GenericForeignKey('content_type', 'object_id')
-    relation_type = models.CharField(verbose_name=_('relation type'),
-        max_length="200",
+    content_object = GenericForeignKey('content_type', 'object_id')
+    relation_type = models.CharField(
+        verbose_name=_('relation type'),
+        max_length=200,
         blank=True,
         null=True,
         help_text=_("A generic text field to tag a relation, like 'leadphoto'."))
@@ -133,10 +142,10 @@ class CategoryRelation(models.Model):
     objects = CategoryRelationManager()
 
     def __unicode__(self):
-        return u"CategoryRelation"
+        return "CategoryRelation"
 
 try:
-    from south.db import db  # South is required for migrating. Need to check for it
+    from south.db import db  # noqa, South is required for migrating. Need to check for it
     from django.db.models.signals import post_syncdb
     from categories.migration import migrate_app
     post_syncdb.connect(migrate_app)
