@@ -1,10 +1,10 @@
 from django.conf import settings
 from django.db.models import Q
 from django.utils.translation import ugettext_lazy as _
+import collections
 
 DEFAULT_SETTINGS = {
     'ALLOW_SLUG_CHANGE': False,
-    'RELATION_MODELS': [],
     'M2M_REGISTRY': {},
     'FK_REGISTRY': {},
     'THUMBNAIL_UPLOAD_PATH': 'uploads/categories/thumbnails',
@@ -18,9 +18,9 @@ DEFAULT_SETTINGS = {
 DEFAULT_SETTINGS.update(getattr(settings, 'CATEGORIES_SETTINGS', {}))
 
 if DEFAULT_SETTINGS['SLUG_TRANSLITERATOR']:
-    if callable(DEFAULT_SETTINGS['SLUG_TRANSLITERATOR']):
+    if isinstance(DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'], collections.Callable):
         pass
-    elif isinstance(DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'], basestring):
+    elif isinstance(DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'], str):
         from django.utils.importlib import import_module
         bits = DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'].split(".")
         module = import_module(".".join(bits[:-1]))
@@ -36,7 +36,7 @@ else:
 # Add all the keys/values to the module's namespace
 globals().update(DEFAULT_SETTINGS)
 
-RELATIONS = [Q(app_label=al, model=m) for al, m in [x.split('.') for x in RELATION_MODELS]]
+RELATIONS = [Q(app_label=al, model=m) for al, m in [x.split('.') for x in DEFAULT_SETTINGS['RELATION_MODELS']]]
 
 # The field registry keeps track of the individual fields created.
 #  {'app.model.field': Field(**extra_params)}
