@@ -1,7 +1,8 @@
 from django import template
-from django.db.models import get_model
-from django.template import (Node, TemplateSyntaxError, VariableDoesNotExist,
-                             FilterExpression)
+from django.apps import apps
+from django.template import (Node, TemplateSyntaxError, VariableDoesNotExist)
+from django.template.base import FilterExpression
+from django.utils.six import string_types
 from categories.base import CategoryBase
 from categories.models import Category
 from mptt.utils import drilldown_tree_for_node
@@ -30,8 +31,8 @@ def get_cat_model(model):
     Return a class from a string or class
     """
     try:
-        if isinstance(model, basestring):
-            model_class = get_model(*model.split("."))
+        if isinstance(model, string_types):
+            model_class = apps.get_model(*model.split("."))
         elif issubclass(model, CategoryBase):
             model_class = model
         if model_class is None:
@@ -53,8 +54,7 @@ def get_category(category_string, model=Category):
     if len(cat_list) == 0:
         return None
     try:
-        categories = model_class.objects.filter(name=cat_list[-1],
-                                          level=len(cat_list) - 1)
+        categories = model_class.objects.filter(name=cat_list[-1], level=len(cat_list) - 1)
         if len(cat_list) == 1 and len(categories) > 1:
             return None
         # If there is only one, use it. If there is more than one, check
@@ -119,13 +119,13 @@ def get_category_drilldown(parser, token):
                 '{%% %(tagname)s category_obj as varname %%}.'
     if len(bits) == 4:
         if bits[2] != 'as':
-            raise template.TemplateSyntaxError, error_str % {'tagname': bits[0]}
+            raise template.TemplateSyntaxError(error_str % {'tagname': bits[0]})
         if bits[2] == 'as':
             varname = bits[3].strip("'\"")
             model = "categories.category"
     if len(bits) == 6:
         if bits[2] not in ('using', 'as') or bits[4] not in ('using', 'as'):
-            raise template.TemplateSyntaxError, error_str % {'tagname': bits[0]}
+            raise template.TemplateSyntaxError(error_str % {'tagname': bits[0]})
         if bits[2] == 'as':
             varname = bits[3].strip("'\"")
             model = bits[5].strip("'\"")
@@ -186,7 +186,7 @@ def display_drilldown_as_ul(category, using='categories.Category'):
     cat = get_category(category, using)
     if cat is None:
         return {'category': cat, 'path': []}
-    else:                          
+    else:
         return {'category': cat, 'path': drilldown_tree_for_node(cat)}
 
 
@@ -264,9 +264,8 @@ def get_top_level_categories(parser, token):
     return TopLevelCategoriesNode(varname, model)
 
 
-def get_latest_objects_by_category(category, app_label, model_name, set_name,
-                                    date_field='pub_date', num=15):
-    m = get_model(app_label, model_name)
+def get_latest_objects_by_category(category, app_label, model_name, set_name, date_field='pub_date', num=15):
+    m = apps.get_model(app_label, model_name)
     if not isinstance(category, CategoryBase):
         category = Category.objects.get(slug=str(category))
     children = category.children.all()
@@ -303,8 +302,7 @@ class LatestObjectsNode(Node):
         date_field = resolve(self.date_field, context)
         num = resolve(self.num, context)
 
-        result = get_latest_objects_by_category(category, app_label, model_name,
-                            set_name, date_field, num)
+        result = get_latest_objects_by_category(category, app_label, model_name, set_name, date_field, num)
         context[self.var_name] = result
 
         return ''
@@ -338,8 +336,7 @@ def do_get_latest_objects_by_category(parser, token):
         num = FilterExpression(bits[6], parser)
     else:
         num = FilterExpression(None, parser)
-    return LatestObjectsNode(var_name, category, app_label, model_name, set_name,
-                     date_field, num)
+    return LatestObjectsNode(var_name, category, app_label, model_name, set_name, date_field, num)
 
 register.tag("get_latest_objects_by_category", do_get_latest_objects_by_category)
 
@@ -368,8 +365,7 @@ def tree_queryset(value):
         # will already be in include_pages when they are checked, thus not
         # trigger additional queries.
         for p in qs2.order_by('rght').iterator():
-            if p.parent_id and p.parent_id not in include_pages and \
-                               p.id not in include_pages:
+            if p.parent_id and p.parent_id not in include_pages and p.id not in include_pages:
                 ancestor_id_list = p.get_ancestors().values_list('id', flat=True)
                 include_pages.update(ancestor_id_list)
 
