@@ -17,16 +17,17 @@ except ImportError:
 from .models import Category
 
 
-def category_detail(request, path,
-    template_name='categories/category_detail.html', extra_context={}):
+def category_detail(request, path, template_name='categories/category_detail.html', extra_context={}):
     path_items = path.strip('/').split('/')
     if len(path_items) >= 2:
-        category = get_object_or_404(Category,
+        category = get_object_or_404(
+            Category,
             slug__iexact=path_items[-1],
             level=len(path_items) - 1,
             parent__slug__iexact=path_items[-2])
     else:
-        category = get_object_or_404(Category,
+        category = get_object_or_404(
+            Category,
             slug__iexact=path_items[-1],
             level=len(path_items) - 1)
 
@@ -63,14 +64,14 @@ class CategoryDetailView(DetailView):
 
     def get_object(self, **kwargs):
         if self.path_field not in self.kwargs:
-            raise AttributeError(u"Category detail view %s must be called with "
-                                 u"a %s." % self.__class__.__name__, self.path_field)
+            raise AttributeError("Category detail view %s must be called with "
+                                 "a %s." % self.__class__.__name__, self.path_field)
         if self.queryset is None:
             queryset = self.get_queryset()
         try:
-            return get_category_for_path(self.kwargs[self.path_field])
+            return get_category_for_path(self.kwargs[self.path_field], self.model.objects.all())
         except ObjectDoesNotExist:
-            raise Http404(_(u"No %(verbose_name)s found matching the query") %
+            raise Http404(_("No %(verbose_name)s found matching the query") %
                           {'verbose_name': queryset.model._meta.verbose_name})
 
     def get_template_names(self):
